# Configure document

## Complete configuration

```yml
# serverless.yml

MyCDN:
  component: '@serverless/tencent-cdn'
  inputs:
    host: abc.com
    hostType: cos
    origin: ww.test.com
    backupOrigin: ww.test.com
    serviceType: web
    fullUrl: on
    fwdHost: ww.test.com
    cache:
      - type: 0
        rule: all
        time: 1000
      - type: 0
        rule: all
        time: 1000
    cacheMode: simple
    refer:
      - type: 1
        list:
          - 'qq.baidu.com'
          - '*.baidu.com'
    accessIp:
      type: 1
      list:
        - '1.2.3.4'
        - '2.3.4.5'
    https:
      certId: 123
      cert: 123
      privateKey: 123
      http2: off
      httpsType: 2
      forceSwitch: -2
```

## Configuration description

Main param description

| 参数名称     | 是否必选 | 默认     | 描述                                                                                                                                                        |
| ------------ | -------- | -------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------- |
| host         | 是       |          | 需要接入的 CDN 域名。                                                                                                                                       |
| projectId    | 是       | ''       | 项目 ID，指域名要添加入的项目的对应 ID，[查看已有项目及 ID](https://console.cloud.tencent.com/project)。                                                    |
| hostType     | 是       | 'cos'    | 域名的接入方式<br/>"cname" ：使用自有源站。<br/>"cos"：设置为 cos 源站。                                                                                    |
| origin       | 是       |          | 源站设置，支持配置一个域名，或多个源站 IP。<br/>端口可配置区间 0 - 65535<br/>域名模式：`www.test.com`<br/>IP 模式：1.1.1.1;2.2.2.2                          |
| backupOrigin | 否       |          | 备份源站设置，支持配置一个域名，或多个源站 IP。<br/>端口可配置区间 0 - 65535<br/>域名模式：`www.test.com`<br/>IP 模式：1.1.1.1;2.2.2.2<br/>默认无备站配置。 |
| serviceType  | 否       | 'web'    | 加速类型设置<br/>"web"：静态内容加速。<br/>"download"：下载文件加速。<br/>"media"：流媒体点播加速。                                                         |
| fullUrl      | 否       |          | 过滤参数设置<br/>"on"：关闭过滤参数。<br/>"off"：开启过滤参数。<br/>下载/点播/直播类型，默认开启过滤参数。<br/>静态类型默认关闭过滤参数。                   |
| fwdHost      | 否       |          | 回源域名配置，默认为加速域名。<br/>注意：COS 源站接入时，fwdHost 需要与 origin 保持一致。                                                                   |
| cache        | 否       |          | 缓存过期时间设置，默认为全部文件 30 天，详细说明见下文。                                                                                                    |
| cacheMode    | 否       | 'simple' | 缓存模式设置<br/>"simple"：表示缓存完全依赖控制台设置。<br/>"custom"：表示缓存依赖控制台设置的缓存时间和源站吐出的 max-age 的最小值。                       |
| refer        | 否       | ''       | 防盗链设置，详细说明见下文。                                                                                                                                |
| accessIp     | 否       | ''       | IP 黑白名单配置，详细说明见下文。                                                                                                                           |

#### cache

| 参数名称 | 是否必选 | 默认 | 描述                                                                                                                                                                                                               |
| -------- | -------- | ---- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| type     | 是       | 0    | 缓存类型<br/> - 0：全部类型，表示匹配所有文件，默认缓存配置。<br/>- 1：文件类型，表示按文件后缀匹配。<br/>- 2：文件夹类型，表示按目录匹配。<br/>- 3：全路径匹配。                                                  |
| rule     | 是       |      | 匹配规则，对应第一个参数的缓存类型 <br>- 0：固定填充 “all”，表示所有文件。<br>- 1：后缀，.jps;.js 等，`;` 分隔。<br>- 2：目录，如 /www/anc;/a/b 等，`;`分隔。<br>- 3：全路径，如 /a/1.html;/b/2.html 等，`;`分隔。 |
| time     | 是       |      | 缓存过期时间，单位为秒                                                                                                                                                                                             |

**参数示例**

```
[[0,"all",1000],[1,".jpg;.js",2000],[2,"/a;/www/b",3000],[3,"/a/1.html;/b/2.html",1000]]
```

填入规则的优先级，从前往后，从低到高。

#### refer

| 参数名称 | 是否必选 | 默认 | 描述                                                                             |
| -------- | -------- | ---- | -------------------------------------------------------------------------------- |
| type     | 是       | 0    | refer 类型<br/> - 0： 不设置防盗链。<br/>- 1：设置黑名单。<br/>- 2：设置白名单。 |
| list     | 是       |      | 具体的名单列表                                                                   |
| empty    | 是       |      | 是否包含空 refer<br>- 1：包含空 refer。<br>- 0：不包含空 refer。                 |

**参数示例**

```
[1,["qq.baidu.com", "*.baidu.com"],1]
```

#### accessIp

| 参数名称 | 是否必选 | 默认 | 描述                                                                                                     |
| -------- | -------- | ---- | -------------------------------------------------------------------------------------------------------- |
| type     | 是       | 0    | 黑名单类型<br/> - 1：黑名单。<br>- 2：白名单。                                                           |
| list     | 是       |      | 对应的黑名单 IP 列表，支持/8、/16、/24 格式的网段设置。最多可设置 100 条 IP 黑名单，或者 50 条 IP 白名单 | b |

**参数示例**

```
{"type":1,"list":["1.2.3.4","2.3.4.5"]}
```

#### https

| 参数名称    | 是否必选 | 默认  | 描述                                                                                                                                                                                                                                                                                                                                                  |
| ----------- | -------- | ----- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| httpsType   | 否       |       | Int 配置类型设置 <br> "0" ：清除 HTTPS 配置，无需填写证书及私钥参数<br>"1"：上传自有证书，并 HTTP 回源<br>"2"：上传自有证书，并协议跟随回源<br>"3"：使用托管证书，并 HTTP 回源<br>"4"：使用托管证书，并 协议跟随回源<br>1&2 名未配置证书或配置的是自有证书，则 必须上传 cert 及 privateKey<br>3&4 域名未配置证书或配置的是托管证书，则必须传递 certId |
| cert        | 否       |       | PEM 格式证书，内容必须 `Base64` 编码, 或者是证书路径，如果是相对路径，则是相对当前项目根目录的路径                                                                                                                                                                                                                                                    |
| privateKey  | 否       |       | PEM 格式私钥，内容必须 `Base64` 编码, 或者是私钥路径，如果是相对路径，则是相对当前项目根目录的路径                                                                                                                                                                                                                                                    |
| forceSwitch | 否       | `-2`  | 强制跳转开关<br>"1"：HTTP 强制跳转<br>"-1"：关闭 HTTP 强制跳转<br>"2"：开启 HTTPS 强制跳转（302）<br>"-2"：关闭 HTTPS 强制跳转（302）<br>"3"：开启 HTTPS 强制跳转（301）<br>"-3"：关闭 HTTPS 强制跳转（301）<br> 如果开启 `http2`，此参数必须配置为 `2`，开启 HTTPS 强制跳转（302）                                                                   |
| http2       | 否       | 'off' | HTTP2.0 开关 <br>"on"：开启 HTTP2.0<br>"off"：关闭 HTTP2.0                                                                                                                                                                                                                                                                                            |
| certId      | 否       |       | 证书 ID，可通过接口 查询托管证书列表获取，如果设置此项，优先使用它，即使设置了 `cert` 和 `privateKey`                                                                                                                                                                                                                                                 |
